@@ -27,7 +27,7 @@ from django.db import models
 from django_restricted_resource.utils import filter_bogus_users
 
 
-class RestrictedResourceManager(models.Manager):
+class RestrictedResourceQuerySet(models.QuerySet):
     """
     Model manager for RestrictedResource and subclasses that has
     additional methods.
@@ -115,3 +115,7 @@ class RestrictedResourceManager(models.Manager):
         # None gets mapped to users, there is no chance to get None here
         assert group is not None
         return self.filter(group=group)
+
+
+RestrictedResourceManager = models.Manager.from_queryset(
+    RestrictedResourceQuerySet)
